@@ -11,6 +11,17 @@ def convert_from_camel_case(name):
     return all_cap_re.sub(r'\1_\2', s1).lower()
 
 
+class EconomicAPIException(Exception):
+    pass
+
+
+class PermissionDenied(EconomicAPIException):
+    pass
+
+
+class ResourceDoesNotExist(EconomicAPIException):
+    pass
+
 def economic_request(auth, url, limit=1000, skip_pages=0):
     url = u"%s?pagesize=%s&skippages=%s" % (url, limit, skip_pages)
     r = requests.get(
@@ -18,5 +29,11 @@ def economic_request(auth, url, limit=1000, skip_pages=0):
         data=json.dumps({}),
         headers={'content-type': 'application/json', 'appId': auth.app_id, 'accessId': auth.token}
     )
-    assert r.status_code == 200, "Unexpected response: %s" % r.content
-    return json.loads(r.content)
\ No newline at end of file
+    if r.status_code == 200:
+        return json.loads(r.content)
+    elif r.status_code == 401:
+        raise PermissionDenied()
+    elif r.status_code == 404:
+        raise ResourceDoesNotExist()
+    else:
+        raise EconomicAPIException(r.content)
\ No newline at end of file
